package edu.stanford.db.rdf.model.i;

import org.w3c.rdf.model.*;
import edu.stanford.db.xml.util.QName;

public class ResourceImpl extends RDFNodeImpl implements Resource {

  protected QName qname;

  public ResourceImpl(int nodeID, QName qname) throws ModelException {

    super(nodeID);
    this.qname = qname;
    if(qname.getLocalName() == null)
      throw new ModelException("Local name cannot be null");
  }

  protected ResourceImpl() {
  }

  /*
  public ResourceImpl(int nodeID, String namespace, String localName) {

    super(nodeID);
    this.namespace = namespace;
    this.localName = localName;
  }
  */

  public String getNamespace() {

    return qname.getNamespace();
  }

  public String getLocalName() {

    return qname.getLocalName();
  }

  public String getURI() {

    //    System.err.println("HERE");
    if(qname == null)
      return "<null>";
    else
      return (getNamespace() == null ? getLocalName() : getNamespace() + getLocalName());
  }

  public String getLabel() {

    return getURI();
  }

  public boolean equals(Object that) {
    
    if(this == that)
      return true;
    
    if(that instanceof ResourceImpl)
      return false;
    
    if(!(that instanceof Resource) || (that instanceof Statement))
      return false; // that's the beauty, this==that must have worked

    Resource t = (Resource)that;

    // resources are equal iff this.getURI() == that.getURI()
    // the case distinction below is for optimization only to avoid unnecessary string concatenation
    
    try {
      if(getNamespace() == null) {
	if(t.getNamespace() == null)
	  return getLocalName().equals(t.getLocalName());
	else // maybe "that" did not detect names
	  return getLocalName().equals(t.getURI());
      } else {
	if(t.getNamespace() != null)
	  return getLocalName().equals(t.getLocalName()) && getNamespace().equals(t.getNamespace());
	else // maybe "this" did not detect names
	  return getURI().equals(t.getURI());
      }
    } catch (ModelException any) {
    }

    return false;
  }
}
